from dataclasses import dataclass


@dataclass
class ColorSet:
    COLOR_MODE_RESET = "0"
    COLOR_MODE_BOLD = "1"
    COLOR_MODE_DIM = "2"
    COLOR_MODE_ITALIC = "3"
    COLOR_MODE_UNDERLINE = "4"
    COLOR_MODE_BLINK = "5"
    COLOR_MODE_INVERSE = "7"
    COLOR_MODE_HIDDEN = "8"
    COLOR_MODE_STRIKETHROUGH = "9"

    COLOR_FG_BLACK = "30"
    COLOR_FG_RED = "31"
    COLOR_FG_GREEN = "32"
    COLOR_FG_YELLOW = "33"
    COLOR_FG_BLUE = "34"
    COLOR_FG_MAGENTA = "35"
    COLOR_FG_CYAN = "36"
    COLOR_FG_WHITE = "37"
    COLOR_FG_DEFAULT = "39"

    COLOR_FG_LIGHT_BLACK = "90"
    COLOR_FG_LIGHT_RED = "91"
    COLOR_FG_LIGHT_GREEN = "92"
    COLOR_FG_LIGHT_YELLOW = "93"
    COLOR_FG_LIGHT_BLUE = "94"
    COLOR_FG_LIGHT_MAGENTA = "95"
    COLOR_FG_LIGHT_CYAN = "96"
    COLOR_FG_LIGHT_WHITE = "97"

    COLOR_BG_BLACK = "40"
    COLOR_BG_RED = "41"
    COLOR_BG_GREEN = "42"
    COLOR_BG_YELLOW = "43"
    COLOR_BG_BLUE = "44"
    COLOR_BG_MAGENTA = "45"
    COLOR_BG_CYAN = "46"
    COLOR_BG_WHITE = "47"
    COLOR_BG_DEFAULT = "49"

    COLOR_BG_LIGHT_BLACK = "100"
    COLOR_BG_LIGHT_RED = "101"
    COLOR_BG_LIGHT_GREEN = "102"
    COLOR_BG_LIGHT_YELLOW = "103"
    COLOR_BG_LIGHT_BLUE = "104"
    COLOR_BG_LIGHT_MAGENTA = "105"
    COLOR_BG_LIGHT_CYAN = "106"
    COLOR_BG_LIGHT_WHITE = "107"

    COLOR_FG_256 = "38;5;"
    COLOR_BG_256 = "48;5;"

    COLOR_FG_RGB = "38;2;"
    COLOR_BG_RGB = "48;2;"
