from dataclasses import dataclass


@dataclass
class Data:
    title = "Default Value"
    underline = "Default Value"
    OS = "Default Value"
    Host = "Default Value"
    Kernel = "Default Value"
    Uptime = "Default Value"
    # Packages = ""
    Shell = "Default Value"
    # Resolution = ""
    # DE = ""
    # WM = ""
    # WM_Theme = ""
    # Terminal = ""
    CPU = "Default Value"
    GPU = ["Default Value"]
    Memory = "Default Value"
    NIC = ["Default Value"]
    NPU = ["Default Value"]
